# lite-merge
<div>
    <a href="https://www.npmjs.com/package/lite-merge"><img src="https://img.shields.io/npm/v/lite-merge.svg" alt="NPM version" /></a>
    <a href="https://www.npmjs.com/package/lite-merge"><img src="https://img.shields.io/npm/dt/lite-merge.svg" alt="NPM downloads" /></a>
    <a href="https://www.patreon.com/fataussiedev"><img src="https://img.shields.io/badge/donate-patreon-F96854" alt="Patreon" /></a>
</div>
A lightweight deep merging object handler, useful if you need to combine an object or group of objects into one single object overwriting/creating keys and values.

## Getting Started
First you'll need to install the **npm package**
```
npm install lite-merge
```
Then you'll need to require it into your code.
```
var merge = require('lite-merge');
```

## Examples
To merge an object(or objects) into an already existing object is simple, firstly you'll need to create the objects.
For this example I'll be making two objects, one that handles letters and the other numbers.
```
let letters = { letters: ['a', 'b', 'c'] },
    numbers = { numbers: { 1: 'one', 2: 'two', 3: 'three' } };
```
As you can see the letters object has a key of 'letters' and its value is an array, where the numbers object has a key of 'numbers' and its value is another object.

Next we'll be creating the target object, for this example it will be an empty object.
```
let target = {};
```

Now for some merging, to merge more than one object with the targetted object you'll need to provide them inside an array.
If you only wish to combine one object to another the array is not required.
```
merge([letters, numbers], target)
```
And that's it, if you console log the merge function you'll see that it returns the newly created object which should look something like this,
```
{
  letters: ['a', 'b', 'c'],
  numbers: { 1: 'one', 2: 'two', 3: 'three' }
}
```

I know what you're thinking.. that's not really that impressive.. and you're right, you could just do everything I told you by using the object assign method. But lets try this.. lets try merging two objects together but each contains a sub-object of letters and numbers with different values and even a string variable that will be changed during merging called 'favourite'
```
let object = { stuff: { letters: ['d', 'e', 'f'], numbers: { 4: 'four', 5: 'five', 6: 'six' } }, settings: { favourite: 'e' } },
    target = { stuff: { letters: ['a', 'b', 'c'], numbers: { 1: 'one', 2: 'two', 3: 'three' } }, settings: { favourite: 'a' } }
    
merge(object, target)
```
If you were to console log this merge it would show something like this,
```
{
  stuff: {
    letters: ['a', 'b', 'c', 'd', 'e', 'f'],
    numbers: { 1: 'one', 2: 'two', 3: 'three', 4: 'four', 5: 'five', 6: 'six' }
  },
  settings: {
    favourite: 'e'
  }
}
```
This is something the default object assign cannot do, this is called deep merging and even the sub-object can be merged down further steps. Allowing you *total control* of the object merging no matter the depth of the object or it's sub-objects.